@@ -1,6 +1,6 @@
 /*******************************************************************
 *
-* This file is part of the KDE project "Bovo"
+* Copyright 2007  Aron Boström <c02ab@efd.lth.se>
 *
 * Bovo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -23,9 +23,9 @@
 
 #include "game.h"
 
-#include <QtCore/QTimer>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
+#include <QTimer>
+#include <QString>
+#include <QStringList>
 
 #include "ai.h"
 #include "aifactory.h"
@@ -40,8 +40,8 @@ using namespace ai;
 namespace bovo
 {
 
-Game::Game(const Dimension& dimension, Player startingPlayer, 
-           KgDifficultyLevel::StandardLevel skill, DemoMode demoMode, 
+Game::Game(const Dimension& dimension, Player startingPlayer,
+           KgDifficultyLevel::StandardLevel skill, DemoMode demoMode,
            unsigned int playTime, AiFactory* aiFactory)
   : m_aiFactory(aiFactory), m_curPlayer(startingPlayer),m_computerMark(O),
   m_demoMode(demoMode), m_inUndoState(false), m_playerMark(X),
@@ -59,8 +59,8 @@ Game::Game(const Dimension& dimension, Player startingPlayer,
             this,  SLOT(move(const Move&)));
 }
 
-Game::Game(const Dimension& dimension, const QStringList &restoreGame, 
-	   KgDifficultyLevel::StandardLevel skill, unsigned int playTime,
+Game::Game(const Dimension& dimension, const QStringList &restoreGame,
+           KgDifficultyLevel::StandardLevel skill, unsigned int playTime,
            AiFactory* aiFactory)
   : m_aiFactory(aiFactory), m_computerMark(O), m_demoMode(NotDemo),
   m_inUndoState(false), m_playerMark(X), m_playTime(playTime),
@@ -72,15 +72,15 @@ Game::Game(const Dimension& dimension, const QStringList &restoreGame,
     m_stepCount = 0;
     m_curPlayer = No;
     foreach (const QString &turn, restoreGame) {
-        QStringList tmp = turn.split(':');
+        QStringList tmp = turn.split(QLatin1Char(':'));
         if (tmp.count() != 2) {
             qFatal("Wrong save file format!");
         }
-        Player tmpPlayer = (tmp[0] == "1") ? X : O;
+        Player tmpPlayer = (tmp[0] == QLatin1String("1")) ? X : O;
         if (m_curPlayer == No) {
             m_curPlayer = tmpPlayer;
         }
-        tmp = tmp[1].split(',');
+        tmp = tmp[1].split(QLatin1Char(','));
         if (tmp.count() != 2) {
             qFatal("Wrong save file format!");
         }
@@ -145,20 +145,20 @@ bool Game::save(const QString& filename) const {
     Q_UNUSED( filename );
 
     QString fileContent;
-    fileContent.append(QString("<bovo width=\"%1\" height=\"%2\">")
-            .arg("").arg(""));
+    fileContent.append(QStringLiteral("<bovo width=\"%1\" height=\"%2\">")
+            .arg(QStringLiteral("")).arg(QStringLiteral("")));
     foreach (const Move &move, m_history) {
-        fileContent.append(QString("<move player=\"%1\" x=\"%2\" y=\"%3\" />").
+        fileContent.append(QStringLiteral("<move player=\"%1\" x=\"%2\" y=\"%3\" />").
                 arg(move.player()).arg(move.x()).arg(move.y()));
     }
-    fileContent.append("</bovo>");
+    fileContent.append(QLatin1String("</bovo>"));
     return false;
 }
 
 QStringList Game::saveLast() const {
     QStringList save;
     foreach (const Move &move, m_history) {
-        save << QString("%1:%2,%3").arg(move.player())
+        save << QStringLiteral("%1:%2,%3").arg(move.player())
                 .arg(move.x()).arg(move.y());
     }
     return save;
